@@ -1,4 +1,4 @@
-from pathlib import Path
+import uuid
 
 from df_engine.core.context import Context
 import pytest
@@ -12,11 +12,11 @@ def testing_context():
 @pytest.fixture(scope="function")
 def testing_file(tmpdir_factory):
     filename = tmpdir_factory.mktemp("data").join("file.db")
-    Path(filename).touch()
     string_file = str(filename)
     yield string_file
 
 
 @pytest.fixture(scope="function")
-def testing_telegram_id():
-    yield "123123123"
+def context_id():
+    ctx_id = str(uuid.uuid4())
+    yield ctx_id
